@@ -155,6 +155,17 @@ Roadmap :
 ◦ Fix help text (Wrong shortcut for cut)
 ◦ Fix welcome screen new button bug
 
+•Version 3.0.11 :
+◦ Fix CTRL-S shortcut
+◦ Fix html syntax
+
+•Version 3.0.12 :
+◦ Link to bugtracker
+◦ Some minor fix due to check with pylint
+◦ Fix settings window title : #9001
+◦ Fix about menu : #9326
+◦ Fix line number : #8814
+
 •Version 3.3.0 :
 ◦ Plugins
 ◦ Snippet
