@@ -37,7 +37,7 @@ class Prefs():
     prefs = cPickle.dump(self.prefs_dict,f)
 
   def edit(self,parent_window):      
-    dialog = gtk.Dialog('Preferences',parent_window,gtk.DIALOG_DESTROY_WITH_PARENT,(gtk.STOCK_OK,gtk.RESPONSE_ACCEPT))
+    dialog = gtk.Dialog('PyGTKEditor - Settings',parent_window,gtk.DIALOG_DESTROY_WITH_PARENT,(gtk.STOCK_OK,gtk.RESPONSE_ACCEPT))
 
     #hildon_text_completion
     w_hildon_text_completion = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
